@@ -354,6 +354,8 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
             unregisterReceiver(mRemoteControlClientReceiver);
             mRemoteControlClientReceiver = null;
         }
+        if (isVideoPlaying())
+            mMediaPlayer.getVLCVout().detachViews();
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
@@ -893,7 +895,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     private void showNotification() {
         if (VLCApplication.showTvUi())
             return;
-        if (mMediaPlayer.getVLCVout().areViewsAttached()) {
+        if (isPlayingPopup() || mMediaPlayer.getVLCVout().areViewsAttached()) {
             hideNotification();
             return;
         }
@@ -906,6 +908,8 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
             mExecutorService.execute(new Runnable() {
                 @Override
                 public void run() {
+                    if (isPlayingPopup())
+                        return;
                     try {
                         Bitmap cover;
                         String title, artist, album;
@@ -928,6 +932,8 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                         Notification notification = NotificationHelper.createPlaybackNotification(PlaybackService.this,
                                 mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO), title, artist, album,
                                 cover, playing, sessionToken, getSessionPendingIntent());
+                        if (isPlayingPopup())
+                            return;
                         if (!AndroidUtil.isLolliPopOrLater || playing)
                             PlaybackService.this.startForeground(3, notification);
                         else {
@@ -966,7 +972,8 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         mExecutorService.execute(new Runnable() {
             @Override
             public void run() {
-                PlaybackService.this.stopForeground(true);
+                if (!isPlayingPopup())
+                    PlaybackService.this.stopForeground(true);
                 NotificationManagerCompat.from(PlaybackService.this).cancel(3);
             }
         });
@@ -2497,6 +2504,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
 
     public void restartMediaPlayer() {
         mMediaPlayer.setEventListener(null);
+        mMediaPlayer.setVideoTrackEnabled(false);
         if (isVideoPlaying())
             mMediaPlayer.getVLCVout().detachViews();
         final MediaPlayer mp = mMediaPlayer;
