@@ -23,15 +23,15 @@
 
 package org.videolan.vlc.gui.browser;
 
-import android.content.Intent;
 import android.view.View;
 import android.widget.CheckBox;
 
 import org.videolan.medialibrary.media.MediaLibraryItem;
 import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.medialibrary.media.Storage;
-import org.videolan.vlc.MediaParsingService;
 import org.videolan.vlc.VLCApplication;
+import org.videolan.vlc.gui.helpers.MedialibraryUtils;
+import org.videolan.vlc.gui.helpers.ThreeStatesCheckbox;
 import org.videolan.vlc.util.CustomDirectories;
 
 import java.util.ArrayList;
@@ -39,55 +39,64 @@ import java.util.Arrays;
 
 class StorageBrowserAdapter extends BaseBrowserAdapter {
 
-    private ArrayList<String> mMediaDirsLocation;
-    private ArrayList<String> mCustomDirsLocation;
+    private static ArrayList<String> mMediaDirsLocation;
+    private static ArrayList<String> mCustomDirsLocation;
+    private boolean mParsing = false;
 
     StorageBrowserAdapter(BaseBrowserFragment fragment) {
         super(fragment);
         updateMediaDirs();
+        mParsing = VLCApplication.getMLInstance().isWorking();
+    }
+
+    // Deactivate checkboxes while ML is scanning to avoid ML undefined states
+    void setServiceActive(boolean started) {
+        if (started != mParsing) {
+            mParsing = started;
+            notifyDataSetChanged();
+        }
     }
 
     @Override
     public void onBindViewHolder(final ViewHolder holder, int position) {
         final MediaViewHolder vh = (MediaViewHolder) holder;
         MediaLibraryItem storage = getItem(position);
+
         if (storage.getItemType() == MediaLibraryItem.TYPE_MEDIA)
             storage = new Storage(((MediaWrapper)storage).getUri());
         String storagePath = ((Storage)storage).getUri().getPath();
         if (!storagePath.endsWith("/"))
             storagePath += "/";
         boolean hasContextMenu = mCustomDirsLocation.contains(storagePath);
+        boolean checked = ((StorageBrowserFragment) fragment).mScannedDirectory || mMediaDirsLocation.contains(storagePath);
         vh.binding.setItem(storage);
         vh.binding.setHasContextMenu(hasContextMenu);
-        vh.binding.setChecked(((StorageBrowserFragment) fragment).mScannedDirectory || mMediaDirsLocation.contains(storagePath));
-        vh.binding.setCheckEnabled(!((StorageBrowserFragment) fragment).mScannedDirectory);
+        if (checked)
+            vh.binding.browserCheckbox.setState(ThreeStatesCheckbox.STATE_CHECKED);
+        else if (hasDiscoveredChildren(storagePath))
+            vh.binding.browserCheckbox.setState(ThreeStatesCheckbox.STATE_PARTIAL);
+        else
+            vh.binding.browserCheckbox.setState(ThreeStatesCheckbox.STATE_UNCHECKED);
+        vh.binding.setCheckEnabled(!mParsing && !((StorageBrowserFragment) fragment).mScannedDirectory);
         if (hasContextMenu)
             vh.setContextMenuListener();
     }
 
+    private boolean hasDiscoveredChildren(String path) {
+        for (String directory : mMediaDirsLocation)
+            if (directory.startsWith(path))
+                return true;
+        return false;
+    }
+
     public void addItem(MediaLibraryItem item, boolean top, int position) {
         if (item.getItemType() == MediaLibraryItem.TYPE_MEDIA)
-             item = new Storage(((MediaWrapper)item).getUri());
+            item = new Storage(((MediaWrapper)item).getUri());
         else if (item.getItemType() != MediaLibraryItem.TYPE_STORAGE)
             return;
         super.addItem(item, top, position);
     }
 
-    private void removeDir(final String path) {
-        VLCApplication.runBackground(new Runnable() {
-            @Override
-            public void run() {
-                VLCApplication.getMLInstance().removeFolder(path);
-            }
-        });
-    }
-
-    private void addDir(final String path) {
-        Intent intent = new Intent(MediaParsingService.ACTION_DISCOVER, null, VLCApplication.getAppContext(), MediaParsingService.class);
-        intent.putExtra(MediaParsingService.EXTRA_PATH, path);
-        VLCApplication.getAppContext().startService(intent);
-    }
-
     void updateMediaDirs() {
         if (mMediaDirsLocation != null)
             mMediaDirsLocation.clear();
@@ -99,18 +108,13 @@ class StorageBrowserAdapter extends BaseBrowserAdapter {
         mCustomDirsLocation = new ArrayList<>(Arrays.asList(CustomDirectories.getCustomDirectories()));
     }
 
-    protected void openMediaFromView(MediaViewHolder holder, View v) {
-        MediaWrapper mw = new MediaWrapper(((Storage) getItem(holder.getLayoutPosition())).getUri());
-        mw.setType(MediaWrapper.TYPE_DIR);
-        fragment.browse(mw, holder.getLayoutPosition(), holder.binding.browserCheckbox.isChecked());
-    }
-
-    protected void checkBoxAction(View v, String path){
-            boolean isChecked = ((CheckBox) v).isChecked();
-            if (isChecked)
-                addDir(path);
-            else
-                removeDir(path);
-        ((StorageBrowserFragment)fragment).processEvent((CheckBox) v, path);
+    protected void checkBoxAction(View v, String mrl) {
+        ThreeStatesCheckbox tscb = (ThreeStatesCheckbox) v;
+        int state = tscb.getState();
+        if (state == ThreeStatesCheckbox.STATE_CHECKED)
+            MedialibraryUtils.addDir(mrl);
+        else
+            MedialibraryUtils.removeDir(mrl);
+        ((StorageBrowserFragment)fragment).processEvent((CheckBox) v, mrl);
     }
 }
