@@ -23,11 +23,15 @@
 
 package org.videolan.vlc.gui.browser;
 
+import android.content.IntentFilter;
 import android.databinding.DataBindingUtil;
 import android.net.Uri;
 import android.os.Bundle;
+import android.support.annotation.Nullable;
+import android.support.design.widget.Snackbar;
 import android.support.v4.app.Fragment;
 import android.support.v4.app.FragmentTransaction;
+import android.support.v4.content.LocalBroadcastManager;
 import android.support.v4.util.SimpleArrayMap;
 import android.text.TextUtils;
 import android.view.Menu;
@@ -40,6 +44,7 @@ import org.videolan.medialibrary.interfaces.EntryPointsEventsCb;
 import org.videolan.medialibrary.media.MediaLibraryItem;
 import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.medialibrary.media.Storage;
+import org.videolan.vlc.MediaParsingService;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.databinding.BrowserItemBinding;
@@ -56,11 +61,7 @@ public class StorageBrowserFragment extends FileBrowserFragment implements Entry
 
     boolean mScannedDirectory = false;
     SimpleArrayMap<String, CheckBox> mProcessingFolders = new SimpleArrayMap<>();
-
-    public StorageBrowserFragment(){
-        mHandler = new BrowserFragmentHandler(this);
-        ROOT = AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY;
-    }
+    private Snackbar mSnack;
 
     public boolean isSortEnabled() {
         return false;
@@ -78,9 +79,15 @@ public class StorageBrowserFragment extends FileBrowserFragment implements Entry
         mAdapter = new StorageBrowserAdapter(this);
         if (bundle == null)
             bundle = getArguments();
-        if (bundle != null){
+        if (bundle != null)
             mScannedDirectory = bundle.getBoolean(KEY_IN_MEDIALIB);
-        }
+    }
+
+    @Override
+    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
+        super.onViewCreated(view, savedInstanceState);
+        if (mRoot && VLCApplication.showTvUi())
+            mSnack = Snackbar.make(view, R.string.tv_settings_hint, Snackbar.LENGTH_INDEFINITE);
     }
 
     @Override
@@ -92,6 +99,17 @@ public class StorageBrowserFragment extends FileBrowserFragment implements Entry
             setFabPlayVisibility(true);
         }
         VLCApplication.getMLInstance().addEntryPointsEventsCb(this);
+        if (mSnack != null)
+            mSnack.show();
+    }
+
+    @Override
+    public void onResume() {
+        super.onResume();
+        final IntentFilter filter = new IntentFilter(MediaParsingService.ACTION_SERVICE_STARTED);
+        filter.addAction(MediaParsingService.ACTION_SERVICE_ENDED);
+        LocalBroadcastManager.getInstance(VLCApplication.getAppContext()).registerReceiver(mParsingServiceReceiver, filter);
+        ((StorageBrowserAdapter)mAdapter).setServiceActive(mMediaLibrary.isWorking());
     }
 
     @Override
@@ -102,6 +120,8 @@ public class StorageBrowserFragment extends FileBrowserFragment implements Entry
             mFabPlay.setOnClickListener(null);
         }
         VLCApplication.getMLInstance().removeEntryPointsEventsCb(this);
+        if (mSnack != null)
+            mSnack.dismiss();
     }
 
     @Override
@@ -240,4 +260,16 @@ public class StorageBrowserFragment extends FileBrowserFragment implements Entry
             ((StorageBrowserAdapter)mAdapter).updateMediaDirs();
         }
     }
+
+    @Override
+    protected void onParsingServiceFinished() {
+        super.onParsingServiceFinished();
+        ((StorageBrowserAdapter)mAdapter).setServiceActive(false);
+    }
+
+    @Override
+    protected void onParsingServiceStarted() {
+        super.onParsingServiceStarted();
+        ((StorageBrowserAdapter)mAdapter).setServiceActive(true);
+    }
 }
