@@ -21,17 +21,17 @@
 package org.videolan.vlc.gui.tv;
 
 import android.annotation.TargetApi;
-import android.app.Activity;
 import android.app.SearchManager;
 import android.content.Intent;
 import android.os.Build;
 import android.os.Bundle;
 import android.support.v17.leanback.widget.SpeechRecognitionCallback;
+import android.support.v4.app.FragmentActivity;
 
 import org.videolan.vlc.R;
 
 @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
-public class SearchActivity extends Activity {
+public class SearchActivity extends FragmentActivity {
 
     SearchFragment mFragment;
     private static final int REQUEST_SPEECH = 1;
@@ -41,7 +41,7 @@ public class SearchActivity extends Activity {
         super.onCreate(savedInstanceState);
         setContentView(R.layout.tv_search);
 
-        mFragment = (SearchFragment) getFragmentManager()
+        mFragment = (SearchFragment) getSupportFragmentManager()
                 .findFragmentById(R.id.search_fragment);
         Intent intent = getIntent();
         if (Intent.ACTION_SEARCH.equals(intent.getAction()) || "com.google.android.gms.actions.SEARCH_ACTION".equals(intent.getAction())) {
